/**
 ** DefPartida.java
 **
 ** Copyright (C) 1992, 1999, 2007, 2011 Mariano Alvarez Fernandez
 ** [e-mail: malfer at telefonica.net]
 **
 ** This file is part of the Parchis4A program.
 **
 ** Parchis4A is free software: you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
 ** the Free Software Foundation, either version 3 of the License, or
 ** (at your option) any later version.
 **
 ** Parchis4A is distributed in the hope that it will be useful,
 ** but WITHOUT ANY WARRANTY; without even the implied warranty of
 ** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 ** GNU General Public License for more details.
 **
 ** You should have received a copy of the GNU General Public License
 ** along with Parchis4A.  If not, see <http://www.gnu.org/licenses/>.
 **
 **/

package com.fgrim.parchis4a;

public class DefPartida {

    // pawn colors
	public static final int AMAR = 0;
	public static final int AZUL = 1;
	public static final int ROJO = 2;
	public static final int VERD = 3;

	// player types
	public static final int PERSONA = 0;
	public static final int MAQUINA = 1;
	public static final int NOJUEGA = 2;

	public static final int NIVEL0 = 0;
	public static final int NIVEL1 = 1;
	public static final int NIVEL2 = 2;
	public static final int NIVEL3 = 3;

	public int tipo_jugador[];
	public int nivel_maquina[];
	public boolean fin_rapido;
	public boolean finrobot_rapido;
	public boolean dado_manual;
	public int num_jg;
	public int num_jgh;
	public int num_jgr;

	public DefPartida() {
		tipo_jugador = new int[4];
		nivel_maquina = new int[4];
		fin_rapido = false;
		finrobot_rapido = false;
		dado_manual = false;
		num_jg = 0;
		num_jgh = 0;
		num_jgr = 0;
	}
	
	public DefPartida(int tj1, int tj2, int tj3, int tj4,
			int nj1, int nj2, int nj3, int nj4) {
		this();
		set(tj1, tj2, tj3, tj4, nj1, nj2, nj3, nj4);
	}
	
	public DefPartida(int a[]) {
		this();
		set(a);
	}
	
	public DefPartida(DefPartida dp) {
		this();
		set(dp);
	}
	
	public DefPartida(String s) {
		this();
		set(s);
	}
	
	public void set(int tj1, int tj2, int tj3, int tj4,
			int nj1, int nj2, int nj3, int nj4) {
		tipo_jugador[0] = tj1;
		tipo_jugador[1] = tj2;
		tipo_jugador[2] = tj3;
		tipo_jugador[3] = tj4;
		nivel_maquina[0] = nj1;
		nivel_maquina[1] = nj2;
		nivel_maquina[2] = nj3;
		nivel_maquina[3] = nj4;
		this.cuentaJg();
	}

	public void set(int a[]) {
		for (int i=0; i<4; i++) {
			tipo_jugador[i] = a[i];
			nivel_maquina[i] = a[i+4];
		}
		fin_rapido = (a[8] == 1) ? true : false;
		finrobot_rapido = (a[9] == 1) ? true : false;
		dado_manual = (a[10] == 1) ? true : false;
		this.cuentaJg();
	}

	public void set(String s) {
		if (s.length() < 12) return;
		if (s.charAt(1) != '9') return;
		for (int i=0; i<4; i++) {
			int pos = 4 + (i * 2);
			tipo_jugador[i] = Integer.valueOf(s.substring(pos, pos+1));
			nivel_maquina[i] = Integer.valueOf(s.substring(pos+1, pos+2));;
		}
		this.cuentaJg();
	}

	public void set(DefPartida dp) {
		for (int i=0; i<4; i++) {
			tipo_jugador[i] = dp.tipo_jugador[i];
			nivel_maquina[i] = dp.nivel_maquina[i];
		}
		fin_rapido = dp.fin_rapido;
		finrobot_rapido = dp.finrobot_rapido;
		dado_manual = dp.dado_manual;
		num_jg = dp.num_jg;
		num_jgh = dp.num_jgh;
		num_jgr = dp.num_jgr;
	}
	
	int[] toArray() {
		int a[] = new int[11];
		for (int i=0; i<4; i++) {
			a[i] = tipo_jugador[i];
			a[i+4] = nivel_maquina[i];
		}
		a[8] = fin_rapido? 1 : 0;
		a[9] = finrobot_rapido? 1 : 0;
		a[10] = dado_manual? 1 : 0;
		return a;
	}

	public String toString() {
		String s = "v9  ";
		for (int i=0; i<4; i++) {
			s += tipo_jugador[i];
			s += nivel_maquina[i];
		}
		return s;
	}

	public void cuentaJg() {
		num_jg = 0;
		num_jgh = 0;
		num_jgr = 0;
		for (int c=AMAR; c<=VERD; c++) {
			if (tipo_jugador[c] != DefPartida.NOJUEGA) num_jg++;
			if (tipo_jugador[c] == DefPartida.PERSONA) num_jgh++;
			if (tipo_jugador[c] == DefPartida.MAQUINA) num_jgr++;
		}
	}

}
